subreaper

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 19, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package subreaper installs platform-specific orphan-process cleanup for MachineProxy's local process tree. It receives lifecycle context from the command runtime, and feeds the operating system with subreaper, procctl, or job-object setup plus SIGCHLD reaping where available.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Reap

func Reap(ctx context.Context)

Reap collects zombie child processes for the lifetime of ctx. It listens for SIGCHLD and drains all finished children on each tick. When run after Setup it also reaps descendants reparented to us via subreaper / procctl, keeping the process table clean.

func Setup

func Setup() error

Setup makes the current process the "child subreaper" so that double-forked grandchildren are reparented to us instead of pid 1. Combined with Reap this keeps the process table clean.

Types

This section is empty.

Jump to