Documentation
¶
Index ¶
Constants ¶
const LevelTrace = slog.Level(-8)
LevelTrace is a custom level below Debug for high-volume diagnostics such as every command execution and connection keepalive.
Variables ¶
This section is empty.
Functions ¶
func ParseLevel ¶
ParseLevel converts a human-readable level string to a slog.Level.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.