logging

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const LevelTrace = slog.Level(-8)

LevelTrace is a custom level below Debug for high-volume diagnostics such as every command execution and connection keepalive.

Variables

This section is empty.

Functions

func ParseLevel

func ParseLevel(s string) slog.Level

ParseLevel converts a human-readable level string to a slog.Level.

func Setup

func Setup(level string) *slog.Logger

Setup creates and registers a default slog.Logger writing to stderr at the given level. It replaces the custom "TRACE" level name in output.

Types

This section is empty.

Jump to